<?php

class ControllerProductsToStoreByManufacturer extends Controller
{
    private $error = array();
    public function index()
	{
        $this->load->language('products_to_store/by_manufacturer');

        $this->document->title = $this->language->get('heading_title');

		$this->getList();
    }

	public function update()
	{
		$this->load->language('products_to_store/by_manufacturer');
		$this->load->model('products_to_store/by_manufacturer');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateList())
		{
			foreach ($this->request->post['selected'] as $manufacturer_id)
			{
				$this->model_products_to_store_by_manufacturer->updateProductToStore($manufacturer_id);
			}

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			$this->redirect(HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . $url);
    	}
	}

	public function reset()
	{
		$this->load->language('products_to_store/by_manufacturer');
		$this->load->model('products_to_store/by_manufacturer');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateList())
		{
			foreach ($this->request->post['selected'] as $manufacturer_id)
			{
				// update with default store id (0) to reset products
				$this->model_products_to_store_by_manufacturer->updateProductToStore($manufacturer_id, '0');
			}

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			$this->redirect(HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . $url);
    	}
	}

	private function getList()
	{
		$this->load->model('catalog/manufacturer');
		$this->load->model('catalog/product');

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		if (isset($this->request->get['sort'])) {
			$sort = $this->request->get['sort'];
		} else {
			$sort = 'name';
		}

		if (isset($this->request->get['order'])) {
			$order = $this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		$url = '';

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

  		$this->document->breadcrumbs = array();

   		$this->document->breadcrumbs[] = array(
       		'href'      => HTTPS_SERVER . 'index.php?route=common/home&token=' . $this->session->data['token'],
       		'text'      => $this->language->get('text_home'),
      		'separator' => FALSE
   		);

   		$this->document->breadcrumbs[] = array(
       		'href'      => HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . $url,
       		'text'      => $this->language->get('heading_title'),
      		'separator' => ' :: '
   		);

		$this->data['update'] = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer/update&token=' . $this->session->data['token'] . $url;
		$this->data['reset'] = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer/reset&token=' . $this->session->data['token'] . $url;

		$this->data['manufacturers'] = array();

		$data = array(
			'sort'  => $sort,
			'order' => $order,
			'start' => ($page - 1) * $this->config->get('config_admin_limit'),
			'limit' => $this->config->get('config_admin_limit')
		);

		$manufacturer_total = $this->model_catalog_manufacturer->getTotalManufacturers();

		$results = $this->model_catalog_manufacturer->getManufacturers($data);

		// general list of stores 
		$this->load->model('setting/store');
		$this->data['stores'] = $this->model_setting_store->getStores();

    	foreach ($results as $result)
		{
			$action = array();

			$action[] = array(
				'text' => $this->language->get('text_edit'),
				'href' => HTTPS_SERVER . 'index.php?route=catalog/manufacturer/update&token=' . $this->session->data['token'] . '&manufacturer_id=' . $result['manufacturer_id']
			);

			// get the stores this manufacturer is assigned to
			$manufacturer_stores = $this->model_catalog_manufacturer->getManufacturerStores($result['manufacturer_id']);

			// get the product count for this manufacturer
			$product_count = $this->model_catalog_product->getTotalProductsByManufacturerId($result['manufacturer_id']);

			$this->data['manufacturers'][] = array(
				'manufacturer_id' => $result['manufacturer_id'],
				'name'            => $result['name'],
				'stores'		  => $manufacturer_stores,
				'product_count'	  => $product_count,
				'sort_order'      => $result['sort_order'],
				'selected'        => isset($this->request->post['selected']) && in_array($result['manufacturer_id'], $this->request->post['selected']),
				'action'          => $action
			);
		}

		$this->data['heading_title']	= $this->language->get('heading_title');
		$this->data['text_default']		= $this->language->get('text_default');
		$this->data['text_no_results']  = $this->language->get('text_no_results');

		$this->data['column_name']			= $this->language->get('column_name');
		$this->data['column_stores']		= $this->language->get('column_stores');
		$this->data['column_product_count']	= $this->language->get('column_product_count');
		$this->data['column_sort_order']	= $this->language->get('column_sort_order');
		$this->data['column_action']		= $this->language->get('column_action');

		$this->data['button_update'] = $this->language->get('button_update');
		$this->data['button_reset'] = $this->language->get('button_reset');

 		if (isset($this->error['warning'])) {
			$this->data['error_warning'] = $this->error['warning'];
		} else {
			$this->data['error_warning'] = '';
		}

		if (isset($this->session->data['success'])) {
			$this->data['success'] = $this->session->data['success'];

			unset($this->session->data['success']);
		} else {
			$this->data['success'] = '';
		}

		$url = '';

		if ($order == 'ASC') {
			$url .= '&order=DESC';
		} else {
			$url .= '&order=ASC';
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$this->data['sort_name'] = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . '&sort=name' . $url;
		$this->data['sort_product_count'] = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . '&sort=product_count' . $url;
		$this->data['sort_sort_order'] = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . '&sort=sort_order' . $url;

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		$pagination = new Pagination();
		$pagination->total = $manufacturer_total;
		$pagination->page = $page;
		$pagination->limit = $this->config->get('config_admin_limit');
		$pagination->text = $this->language->get('text_pagination');
		$pagination->url = HTTPS_SERVER . 'index.php?route=products_to_store/by_manufacturer&token=' . $this->session->data['token'] . $url . '&page={page}';

		$this->data['pagination'] = $pagination->render();

		$this->data['sort'] = $sort;
		$this->data['order'] = $order;

		$this->template = 'products_to_store/by_manufacturer.tpl';
		$this->children = array(
			'common/header',
			'common/footer'
		);

		$this->response->setOutput($this->render(TRUE), $this->config->get('config_compression'));
	}

	private function validateList()
	{
    	if (!$this->user->hasPermission('modify', 'products_to_store/by_manufacturer')) {
      		$this->error['warning'] = $this->language->get('error_permission');
    	}

    	if (!$this->error) {
			return TRUE;
    	} else {
			if (!isset($this->error['warning'])) {
				$this->error['warning'] = $this->language->get('error_required_data');
			}
      		return FALSE;
    	}
  	}
}

?>